@@ -19,6 +19,10 @@ def post(session):
 def get(session):
     return Titled("Hello, world!", P(str(session)))
 
+@rt("/see-toast-with-typehint")
+def get(session: dict):
+    return Titled("Hello, world!", P(str(session)))
+
 @rt("/see-toast-ft-response")
 def get(session):
     add_toast(session, "Toast FtResponse", "info")
@@ -41,6 +45,13 @@ def test_ft_response():
     res = cli.get('/see-toast-ft-response')
     assert 'Toast FtResponse' in res.text
 
+def test_get_toaster_with_typehint():
+    res = cli.get('/see-toast-with-typehint', follow_redirects=False)
+    assert 'Toast get' in res.text
+
+    res = cli.get('/see-toast-with-typehint', follow_redirects=True)
+    assert 'Toast get' in res.text
+
 test_get_toaster()
 test_post_toaster()
 test_ft_response()
